@@ -5,10 +5,10 @@ from ob_dj_otp.core.otp.models import OneTruePairing
 
 
 class OneTruePairingAdmin(admin.ModelAdmin):
-    """ OneTruePairingAdmin
-    """
+    """OneTruePairingAdmin"""
 
     list_display = (
+        "email",
         "phone_number",
         "usage",
         "status",
