@@ -10,6 +10,4 @@ class OTPConfig(AppConfig):
     verbose_name = _("OTPs")
 
     def ready(self):
-        register(settings_validation.required_settings)
-        register(settings_validation.required_dependencies)
         register(settings_validation.required_installed_apps)
